.. rst-class:: detail

ReadWatch
====================

.. currentmodule:: compas_rrc

.. autoclass:: ReadWatch

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~ReadWatch.__init__
        ~ReadWatch.from_msg
        ~ReadWatch.parse_feedback
    
    